# Generated by roxygen2: do not edit by hand

S3method(print,customDimension_ga)
S3method(print,ga_custom_data_source_upload)
S3method(print,ga_custom_datasource)
S3method(print,ga_model)
S3method(print,ga_model_result)
S3method(print,gar_BetweenFilter)
S3method(print,gar_Filter)
S3method(print,gar_FilterExpression)
S3method(print,gar_InListFilter)
S3method(print,gar_NullFilter)
S3method(print,gar_NumericFilter)
S3method(print,gar_OrderBy)
S3method(print,gar_StringFilter)
export(accountPicker)
export(accountPickerUI)
export(authDropdown)
export(authDropdownUI)
export(dim_filter)
export(filter_clause_ga4)
export(ga_account_list)
export(ga_accounts)
export(ga_adwords)
export(ga_adwords_add_linkid)
export(ga_adwords_delete_linkid)
export(ga_adwords_list)
export(ga_aggregate)
export(ga_allowed_metric_dim)
export(ga_auth)
export(ga_auth_setup)
export(ga_cache_call)
export(ga_clientid_activity)
export(ga_clientid_activity_unnest)
export(ga_clientid_deletion)
export(ga_clientid_hash)
export(ga_custom_datasource)
export(ga_custom_upload)
export(ga_custom_upload_delete)
export(ga_custom_upload_file)
export(ga_custom_upload_list)
export(ga_custom_vars)
export(ga_custom_vars_create)
export(ga_custom_vars_list)
export(ga_custom_vars_patch)
export(ga_data)
export(ga_data_aggregations)
export(ga_data_filter)
export(ga_data_order)
export(ga_experiment)
export(ga_experiment_list)
export(ga_filter)
export(ga_filter_add)
export(ga_filter_apply_to_view)
export(ga_filter_delete)
export(ga_filter_list)
export(ga_filter_update)
export(ga_filter_update_filter_link)
export(ga_filter_view)
export(ga_filter_view_list)
export(ga_goal)
export(ga_goal_add)
export(ga_goal_list)
export(ga_goal_update)
export(ga_meta)
export(ga_model)
export(ga_model_edit)
export(ga_model_example)
export(ga_model_load)
export(ga_model_make)
export(ga_model_refresh)
export(ga_model_save)
export(ga_model_shiny)
export(ga_model_shiny_load)
export(ga_model_shiny_template)
export(ga_model_write)
export(ga_mp_cid)
export(ga_mp_connection)
export(ga_mp_event)
export(ga_mp_event_item)
export(ga_mp_send)
export(ga_remarketing_build)
export(ga_remarketing_create)
export(ga_remarketing_estimate)
export(ga_remarketing_get)
export(ga_remarketing_list)
export(ga_segment_list)
export(ga_trackme)
export(ga_trackme_event)
export(ga_unsampled)
export(ga_unsampled_download)
export(ga_unsampled_list)
export(ga_users_add)
export(ga_users_delete)
export(ga_users_delete_linkid)
export(ga_users_list)
export(ga_users_update)
export(ga_view)
export(ga_view_list)
export(ga_webproperty)
export(ga_webproperty_list)
export(google_analytics)
export(google_analytics_3)
export(google_analytics_4)
export(make_cohort_group)
export(met_filter)
export(metricDimensionSelect)
export(metricDimensionSelectUI)
export(multi_select)
export(multi_selectUI)
export(order_type)
export(pivot_ga4)
export(segmentBuilder)
export(segmentBuilderUI)
export(segment_define)
export(segment_element)
export(segment_ga4)
export(segment_vector_sequence)
export(segment_vector_simple)
exportClasses(.filter_clauses_ga4)
exportClasses(dim_fil_ga4)
exportClasses(dim_ga4)
exportClasses(dynamicSegment_ga4)
exportClasses(met_fil_ga4)
exportClasses(met_ga4)
exportClasses(orFiltersForSegment_ga4)
exportClasses(order_type_ga4)
exportClasses(segmentDef_ga4)
exportClasses(segmentFilterClause_ga4)
exportClasses(segmentFilter_ga4)
exportClasses(segmentSequenceStep_ga4)
exportClasses(segment_ga4)
exportClasses(sequenceSegment_ga4)
exportClasses(simpleSegment_ga4)
import(assertthat)
import(cli)
import(googleAuthR)
importFrom(assertthat,assert_that)
importFrom(assertthat,is.flag)
importFrom(assertthat,is.readable)
importFrom(assertthat,is.string)
importFrom(assertthat,is.writeable)
importFrom(dplyr,across)
importFrom(dplyr,bind_cols)
importFrom(dplyr,bind_rows)
importFrom(dplyr,distinct)
importFrom(dplyr,ends_with)
importFrom(dplyr,filter)
importFrom(dplyr,left_join)
importFrom(dplyr,mutate)
importFrom(dplyr,mutate_if)
importFrom(dplyr,pull)
importFrom(dplyr,rename)
importFrom(dplyr,select)
importFrom(dplyr,transmute)
importFrom(gargle,gargle_oauth_client_from_json)
importFrom(gargle,gargle_oob_default)
importFrom(googleAuthR,gar_api_generator)
importFrom(googleAuthR,gar_api_page)
importFrom(googleAuthR,gar_auth)
importFrom(googleAuthR,gar_auth_configure)
importFrom(googleAuthR,gar_auth_service)
importFrom(googleAuthR,gar_batch_walk)
importFrom(googleAuthR,gar_cache_setup)
importFrom(httr,GET)
importFrom(httr,add_headers)
importFrom(httr,content)
importFrom(httr,progress)
importFrom(httr,stop_for_status)
importFrom(httr,write_disk)
importFrom(jsonlite,flatten)
importFrom(magrittr,"%>%")
importFrom(measurementProtocol,mp_cid)
importFrom(measurementProtocol,mp_connection)
importFrom(measurementProtocol,mp_event)
importFrom(measurementProtocol,mp_event_item)
importFrom(measurementProtocol,mp_send)
importFrom(measurementProtocol,mp_trackme)
importFrom(measurementProtocol,mp_trackme_event)
importFrom(memoise,cache_filesystem)
importFrom(methods,as)
importFrom(methods,is)
importFrom(methods,setClass)
importFrom(methods,setClassUnion)
importFrom(purrr,as_vector)
importFrom(purrr,compact)
importFrom(purrr,map)
importFrom(purrr,map2)
importFrom(purrr,map_chr)
importFrom(purrr,map_dfr)
importFrom(purrr,map_if)
importFrom(purrr,map_lgl)
importFrom(purrr,pmap)
importFrom(purrr,walk)
importFrom(rlang,"!!!")
importFrom(rlang,enquo)
importFrom(rlang,eval_tidy)
importFrom(stats,setNames)
importFrom(tibble,as_tibble)
importFrom(tibble,enframe)
importFrom(tidyr,hoist)
importFrom(tidyr,pivot_wider)
importFrom(tidyr,unnest)
importFrom(tidyr,unnest_longer)
importFrom(tidyr,unnest_wider)
importFrom(tools,file_ext)
importFrom(usethis,ui_yeah)
importFrom(utils,menu)
importFrom(utils,modifyList)
importFrom(utils,write.csv)
importFrom(whisker,whisker.render)
