<img src="https://raw.githubusercontent.com/8-bit-sheep/googleAnalyticsR/master/inst/hexlogo/hex.png" width="120px" />

# googleAnalyticsR

[![CRAN](http://www.r-pkg.org/badges/version/googleAnalyticsR)](https://cran.r-project.org/package=googleAnalyticsR)
[![CRAN Total Downloads](https://cranlogs.r-pkg.org/badges/grand-total/googleAnalyticsR)](https://cranlogs.r-pkg.org/badges/grand-total/googleAnalyticsR)
[![CRAN Monthly Downloads](https://cranlogs.r-pkg.org/badges/googleAnalyticsR)](https://cranlogs.r-pkg.org/badges/googleAnalyticsR)
[![CII Best Practices](https://bestpractices.coreinfrastructure.org/projects/2025/badge)](https://bestpractices.coreinfrastructure.org/projects/2025)

## Install

From CRAN:

```r
install.packages("googleAnalyticsR")
```

Or the latest development version on GitHub:

```r
remotes::install_github("8-bit-sheep/googleAnalyticsR")
```

## Getting started

Examples and tutorials available at [https://8-bit-sheep.com/googleAnalyticsR](https://8-bit-sheep.com/googleAnalyticsR/).
