library(hexSticker)
imgurl <- "inst/hexlogo/googleAnalyticsRlogo.png"
sticker(imgurl, package="googleAnalyticsR", 
        p_size=4, s_x=1, s_y=0.85, s_width=.6,
        filename="inst/hexlogo/hex.png",
        p_color = "#f27f22", p_family = "sans", p_y = 1.45,
        h_color = "#767676", h_fill = "#ffffff")
